/*
 * Copyright (C) 2009, 2010 Hermann Meyer, James Warden, Andreas Degert
 * Copyright (C) 2011 Pete Shorthose
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 * --------------------------------------------------------------------------
 *
 *
 *	This are the cairo callbacks to draw the guitarix UI
 *
 *
 * --------------------------------------------------------------------------
 */

#include "guitarix.h"

/* --------------------------- gx_cairo namespace ------------------------ */
namespace gx_cairo
{

typedef struct {
	const char *icon_name;
	const guint8 *icon_data;
} image_entry;

/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (guitar)
#endif
#ifdef __GNUC__
static const guint8 guitar[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 guitar[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (21600) */
  "\0\0Tx"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (720) */
  "\0\0\2\320"
  /* width (180) */
  "\0\0\0\264"
  /* height (30) */
  "\0\0\0\36"
  /* pixel_data: */
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\0\0\0\377\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\0\0\0\377\0\0\0\377q\0\0"
  "\11\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0TTTcOOO\325JJJ\377NN"
  "N\343UUUU\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0TT"
  "TUJJJ\377OOO\325\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0KKK\377JJJ"
  "\377QQQ\234\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0TTTULLL\377MMM\361\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0TTTULLL\377LLL\377HHH\377EEE\377CCC\377CCC\377BBB\377"
  "DDD\377EEE\377BBB\377EEE\377EEE\377GGG\377QQQ\234\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0KKK\377"
  "LLL\377MMM\377WWW*\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0PPP\252FFF\377FFF\377GGG\377JJJ\377KKK\377PPP\307"
  "SSS\177\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0""333\252---\377***\377\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0""222\252///\377111\325\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0...\377,,,\377///\377\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\0\0\0\377"
  "\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0:::\377\17\17\17\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\21\21\21\377"
  "AAA\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\20\20\20\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0UUUG\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\11\11\11\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\17\17\17\377\20\20\20\377\30\30\30\377\34\34\34"
  "\377\32\32\32\377QQQ\216\377\377\377\0###\377999\377AAA\377FFF\377MM"
  "M\377QQQ\377OOO\377OOO\377OOO\377PPP\377PPP\377PPP\377PPP\377PPP\377"
  "QQQ\377NNN\377EEE\377\377\377\377\0\377\377\377\0\377\377\377\0>>>\377"
  "QQQ\307TTT\234TTT\234VVVqSSS\252EEE\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0JJJ\377TTT\234VVV\177VVV\177WWWcWWWcWWWcYYYGWWWcUUU\177QQQ"
  "\307DDD\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0""555\234===*\77\77\77\16\77\77\77\34:::U888"
  "8\377\377\377\0\377\377\377\0""555\216===8@@@\16\377\377\377\0\77\77"
  "\77\34...\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0(((\377\77\77\77\34\377\377\377\0\377\377\377\0\377\377"
  "\377\0:::U\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\0\0\0\377\0\0\0"
  "\377q\0\0\11\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377q\0\0\11\0\0\0\377"
  "\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0>>>\377\11\11\11\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "111\377\377\377\377\0\377\377\377\0\377\377\377\0RRR\216\7\7\7\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377PPP\307\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0""333\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\24\24\24\377\377\377\377\0\377\377\377\0MMM\361\2\2\2\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377EEE\377FFF\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\26\26\26\377\377\377\377\0\377\377\377\0III\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377TTTc\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0MMM\377\0\0\0\377\0\0\0\377\1\1\1\377\1\1\1\377\5\5\5\377\7"
  "\7\7\377\7\7\7\377\11\11\11\377\13\13\13\377\13\13\13\377\11\11\11\377"
  "\10\10\10\377\31\31\31\377\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0""111\325\0\0\0\377\0\0\0\377\1\1\1\377\1\1\1\377\0\0\0"
  "\377)))\377\377\377\377\0\377\377\377\0\17\17\17\377\11\11\11\377\21"
  "\21\21\377\27\27\27\377\22\22\22\377\16\16\16\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0%%%\377\22\22\22\377\34\34\34\377\37"
  "\37\37\377\35\35\35\377\27\27\27\377\36\36\36\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\0\0\0\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377q\0\0\11\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0WWW\34###\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377&&&\377\377\377\377\0\377\377\377\0\377\377\377\0"
  "CCC\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\7\7\7\377PPP\270\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\32\32\32\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\37\37\37\377\377\377\377\0\377\377"
  "\377\0@@@\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\3\3\3\377CCC\377"
  "BBB\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377222\377\377\377\377\0XXX\16\16\16\16\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "III\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0>>>\377\0\0\0\377\1\1\1\377\3\3\3\377\3\3\3\377\5"
  "\5\5\377\2\2\2\377\5\5\5\377\7\7\7\377\13\13\13\377\17\17\17\377\20\20"
  "\20\377\20\20\20\377\12\12\12\377999\377\377\377\377\0\377\377\377\0"
  "\377\377\377\0\"\"\"\377\0\0\0\377\0\0\0\377\1\1\1\377\2\2\2\377\0\0"
  "\0\377)))\377\377\377\377\0\377\377\377\0%%%\377\7\7\7\377\21\21\21\377"
  "\27\27\27\377\27\27\27\377\17\17\17\377\35\35\35\377\377\377\377\0\377"
  "\377\377\0...\377\22\22\22\377\34\34\34\377\37\37\37\377\36\36\36\377"
  "\30\30\30\377\14\14\14\377999*\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\0\0\0\377\0\0\0\377q\0\0"
  "\11\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0%%%\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\13\13\13\377"
  "\25\25\25\377\27\27\27\377\20\20\20\377\5\5\5\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377>>>\377\377\377\377\0\377\377\377\0\377\377\377\0""666\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\22\22\22\377\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0TTTU\10\10\10\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377333\377\377\377\377\0\377\377\377\0""222\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\13\13\13\377MMM\377QQQ\2349"
  "99\377&&&\377!!!\377\31\31\31\377\17\17\17\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\1\1\1\377\27\27\27\377\32\32\32\377\33\33"
  "\33\377!!!\377000\377WWW*\377\377\377\0<<<\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377>>>\377\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0""444\377\0\0\0\377\1\1\1\377\5\5\5\377\4\4\4\377\13\13\13"
  "\377\32\32\32\377\34\34\34\377\24\24\24\377\10\10\10\377\15\15\15\377"
  "\17\17\17\377\20\20\20\377\14\14\14\377)))\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\27\27\27\377\0\0\0\377\2\2\2\377\4\4\4\377\3\3\3"
  "\377\7\7\7\377444\216\377\377\377\0\377\377\377\0""555c\10\10\10\377"
  "\21\21\21\377\27\27\27\377\30\30\30\377\27\27\27\377\16\16\16\377111"
  "\325222\270\22\22\22\377\32\32\32\377\36\36\36\377\37\37\37\377\34\34"
  "\34\377\6\6\6\377---\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\0\0\0\377q\0\0\11"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0""222\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\22\22\22\377111\377BBB\377III"
  "\377JJJ\377GGG\377>>>\377555\377\"\"\"\377\35\35\35\377TTTU\377\377\377"
  "\0\377\377\377\0\377\377\377\0\"\"\"\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\36\36\36\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0MMM\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377;"
  ";;\377\377\377\377\0\377\377\377\0\32\32\32\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\32\32\32\377\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0QQQ\234444\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377&&&\377III\377TTTqXXX\16\377\377\377\0\377"
  "\377\377\0\377\377\377\0UUUU\7\7\7\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377,,,\377\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0!!!\377\0\0\0\377\3\3\3\377\5\5\5\377\3\3\3\377\34\34\34\377@@@\377"
  "GGG\377000\377\20\20\20\377\16\16\16\377\21\21\21\377\23\23\23\377\14"
  "\14\14\377)))\377\377\377\377\0\377\377\377\0\377\377\377\0\10\10\10"
  "\377\0\0\0\377\3\3\3\377\7\7\7\377\4\4\4\377\10\10\10\377\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\37\37\37\377\14\14\14\377"
  "\27\27\27\377\34\34\34\377\34\34\34\377\27\27\27\377\7\7\7\377\10\10"
  "\10\377\31\31\31\377\37\37\37\377\37\37\37\377\34\34\34\377\7\7\7\377"
  "$$$\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\0\0\0\377\0\0\0\377q\0\0\11\0\0\0"
  "\377\0\0\0\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377q\0\0\11\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0KKK\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\26\26\26\377<<<\377QQQ\252\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0QQQ\252"
  "XXX\16\377\377\377\0\377\377\377\0\377\377\377\0VVV8\21\21\21\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377,,,\377\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0>>>\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377BBB\377\377\377\377\0RRR\216\10\10\10\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377)))\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;;;\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377444\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0""111\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\1\1\1\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\25\25\25\377\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0UUUG\15\15\15\377\0\0\0\377\4\4\4\377"
  "\6\6\6\377\1\1\1\377&&&\377OOO\377WWW\377;;;\377\23\23\23\377\16\16\16"
  "\377\22\22\22\377\23\23\23\377\16\16\16\377999\377\377\377\377\0\377"
  "\377\377\0""555q\3\3\3\377\0\0\0\377\4\4\4\377\7\7\7\377\3\3\3\377\16"
  "\16\16\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0""2"
  "22\270\6\6\6\377\25\25\25\377\35\35\35\377\37\37\37\377\37\37\37\377"
  "\22\22\22\377\34\34\34\377!!!\377!!!\377\37\37\37\377\22\22\22\377\35"
  "\35\35\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\274\261\245\1\377\377\377\0\271\270\303\25\5\5\7\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0!!!\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\5\5\5\377;;;\377XXX\16\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0KKK\377\3\3\3\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377888\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0/"
  "//\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\10\10\10\377MMM\377\377"
  "\377\377\0GGG\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377:"
  "::\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0""777\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377BBB\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0SSS\177\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\24\24\24\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\4\4\4\377X"
  "XX\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0III\377"
  "\3\3\3\377\1\1\1\377\6\6\6\377\6\6\6\377\2\2\2\377///\377NNN\377LLL\377"
  ")))\377\10\10\10\377\20\20\20\377\23\23\23\377\20\20\20\377\32\32\32"
  "\377OOO\325\377\377\377\0\377\377\377\0***\377\0\0\0\377\1\1\1\377\6"
  "\6\6\377\10\10\10\377\1\1\1\377\27\27\27\377\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\27\27\27\377\22\22\22\377"
  "\35\35\35\377!!!\377$$$\377!!!\377!!!\377\"\"\"\377\37\37\37\377\22\22"
  "\22\377\30\30\30\377555c\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\255\244\234i\207~o\377NI=\377"
  "\26\25\21\377\2\2\2\377\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377q\0\0\11\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0WWW8\5\5\5\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377(((\377WWW\34\377\377\377\0\377"
  "\377\377\0\377\377\377\0DDD\377777\377555\377666\377444\377;;;\377PP"
  "P\270\377\377\377\0\377\377\377\0\377\377\377\0DDD\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377III\377\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\36\36\36\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\31\31\31\377UUU8\377\377\377\0@@@\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377III\377\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0'''\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\10\10\10\377SSSq\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0)))\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\35\35\35\377,,,\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377PPP\307\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0BBB\377\0\0\0\377\2\2\2\377\5\5\5\377\6\6\6\377"
  "\5\5\5\377\32\32\32\377'''\377\31\31\31\377\13\13\13\377\14\14\14\377"
  "\20\20\20\377\20\20\20\377\14\14\14\377:::\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0!!!\377\0\0\0\377\3\3\3\377\4\4\4\377\7\7\7\377\3"
  "\3\3\377(((\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0""555U\10\10\10\377\35\35\35\377\"\"\"\377!!!\377!!!"
  "\377!!!\377\35\35\35\377\24\24\24\377\22\22\22\377999\16\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\327\313\270\335\311\265\213\377\232\203R\370\221\205"
  "d\366\"\36\27\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377q"
  "\0\0\11\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0AAA\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377;;;\377\377\377\377\0\377"
  "\377\377\0\377\377\377\0""000\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\27\27\27\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0""888\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\14\14\14"
  "\377SSS\177\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\21"
  "\21\21\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377---\377\377\377\377"
  "\0\377\377\377\0""555\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\6\6"
  "\6\377TTT\216\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\30\30\30\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\30\30\30\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0OOO\307\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377===\377@@@\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377GGG\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "555\377\0\0\0\377\4\4\4\377\7\7\7\377\10\10\10\377\7\7\7\377\6\6\6\377"
  "\7\7\7\377\10\10\10\377\15\15\15\377\17\17\17\377\15\15\15\377\23\23"
  "\23\377222\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\34\34\34\377\0\0\0\377\6\6\6\377\11\11\11\377\10\10\10\377\7\7\7\377"
  "222\270\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\10\10\10\377\31\31\31\377###\377$$$\377$$$\377$"
  "$$\377\35\35\35\377\4\4\4\377555\216\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\373\337\1\335\316\266\377\264\233h\377\272\241a\377\335\305\206\377"
  "\211pD\372\22\17\12\377\0\0\0\377\0\0\0\377q\0\0\11q\0\0\11\0\0\0\377"
  "\0\0\0\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0,,,\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\6\6\6\377GGG\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\20\20\20\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\21\21\21\377WWW\34\377\377\377\0\377\377\377"
  "\0$$$\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\27\27\27\377\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0OOO\325\4\4\4\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377888\377555\1\377\377\377\0\36\36"
  "\36\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\22\22\22\377WWW8\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0WW"
  "W*\6\6\6\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377,,,\377\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\36\36\36\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377'''\377OOO\377III\377\15\15\15"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377555\377\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\33\33\33\377\0\0\0\377\1\1\1\377"
  "\3\3\3\377\6\6\6\377\11\11\11\377\14\14\14\377\14\14\14\377\20\20\20"
  "\377\20\20\20\377\21\21\21\377\22\22\22\377%%%\377PPP\307\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\12\12\12\377\1\1\1\377\10"
  "\10\10\377\12\12\12\377\10\10\10\377\7\7\7\377555\177\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0""111\307\7\7\7\377"
  "\37\37\37\377###\377\"\"\"\377###\377###\377\35\35\35\377\11\11\11\377"
  "999\34\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0""5\377^\1\377\377\377\0\345\331\307\25\340\322\277\377\311\266"
  "\220\377\334\314\237\377\233}G\377\244|8\376fR-\364\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0###\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\13\13"
  "\13\377OOO\325\377\377\377\0\377\377\377\0\377\377\377\0\20\20\20\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\33\33\33"
  "\377\377\377\377\0\377\377\377\0\377\377\377\0\25\25\25\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377&&&\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0@@@\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377CCC\377555\1SSSd\16\16\16\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377%%%\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0MMM\361\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377;;;\377333\1\377\377\377\0\377\377\377\0\377\377\377"
  "\0HHH\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\35\35\35"
  "\377222\377...\377\13\13\13\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\"\"\"\377\377\377\377\0\377\377\377\0\377\377\377\0WWW*\14\14\14\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\2\2\2\377\7\7\7\377"
  "\15\15\15\377\22\22\22\377\22\22\22\377\21\21\21\377\34\34\34\377SSS"
  "\177\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\10\10\10"
  "\377\1\1\1\377\10\10\10\377\12\12\12\377\10\10\10\377\11\11\11\377\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\15\15\15\377\34\34\34\377\"\"\"\377###\377\"\"\"\377###\377"
  "###\377\37\37\37\377\22\22\22\377555c\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0V\345\222\2\377\377\377\0\377\346\353\20\351"
  "\334\323v\335\323\300\377\310\272\231\377\215{V\377t[+\377\227q/\377"
  "\221p4\357\0\0\0\377\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0###\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\6\6\6\377OOO\325\377\377\377\0\377"
  "\377\377\0\377\377\377\0OOO\325---\377\6\6\6\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377,,,\377333\1\377\377\377\0VVVG\14\14\14\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377555\377\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0***\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\16\16\16\377SSSr444\1NNN\343\5\5\5\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377===\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0EEE\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377III\377444\1\377\377\377\0\377\377\377\0\377"
  "\377\377\0\27\27\27\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\20\20\20\377\377\377\377\0\377\377\377\0\377\377\377"
  "\0TTTc\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\17\17\17\377"
  "\25\25\25\377\1\1\1\377\1\1\1\377\11\11\11\377\16\16\16\377\20\20\20"
  "\377\20\20\20\377;;;\377\377\377\377\0\377\377\377\0\377\377\377\0""9"
  "998\1\1\1\377\4\4\4\377\14\14\14\377\15\15\15\377\10\10\10\377\32\32"
  "\32\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\31\31\31\377\24\24\24\377!!!\377$$$\377!!!\377!!!\377$$$\377$"
  "$$\377!!!\377\31\31\31\377!!!\377\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\337\323\276n\335\322"
  "\275\377\301\266\227\377\210zS\377eT*\377\203k;\377\247\210J\377\242"
  "\206N\335\26\24\22\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0//"
  "/\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377CCC\377\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0III\377\21\21\21\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377;;;\377333\1""333\1RRR\216\7"
  "\7\7\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377555\377\377\377\377\0"
  "\377\377\377\0\377\377\377\0TTTq\11\11\11\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377---\377\377\377\377\0""333\1III\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377FFF\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0""444\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\3\3\3\377PPP\252\377\377\377\0\377\377"
  "\377\0\377\377\377\0EEE\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377QQQ\234\377\377\377\0\377\377"
  "\377\0HHH\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377,,,\377"
  "BBB\377000\377\0\0\0\377\0\0\0\377\5\5\5\377\11\11\11\377\11\11\11\377"
  "\24\24\24\377\377\377\377\0\377\377\377\0\377\377\377\0---\377\0\0\0"
  "\377\10\10\10\377\15\15\15\377\14\14\14\377\7\7\7\377$$$\377\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0%%%\377\22\22\22\377"
  "\36\36\36\377\"\"\"\377!!!\377\30\30\30\377\0\0\0\377!!!\377$$$\377$"
  "$$\377\37\37\37\377\21\21\21\377\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\217\3\377\377\377\0\377\377\377\0\340\331\305\233\332\316\264\377\306"
  "\266\226\377\211zV\376^N)\376\203rQ\377\264\240|\375\301\254\201\374"
  "\270\252\205\317\264\261\235@\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\77\77\77\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\21"
  "\21\21\377DDD\377\377\377\377\0\377\377\377\0\377\377\377\0:::\377\1"
  "\1\1\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377AAA\377333\1""333\1M"
  "MM\361\10\10\10\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\31\31\31"
  "\377QQQ\234\377\377\377\0\377\377\377\0///\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377DDD\377\377\377\377\0\377\377\377\0""666"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\1\1\1\377KKK\377\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\36\36\36\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\22\22\22"
  "\377VVV8\377\377\377\0\377\377\377\0\377\377\377\0\16\16\16\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377EEE\377\377\377\377\0\377\377\377\0""777\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377===\377TTTUKKK\377\34\34\34\377\0\0"
  "\0\377\0\0\0\377\1\1\1\377\1\1\1\377\0\0\0\377PPP\325\377\377\377\0\377"
  "\377\377\0\35\35\35\377\0\0\0\377\6\6\6\377\15\15\15\377\15\15\15\377"
  "\11\11\11\377***\377\377\377\377\0\27\27\27\1\377\377\377\0'''\377\22"
  "\22\22\377\35\35\35\377\"\"\"\377\"\"\"\377\32\32\32\377\0\0\0\377\0"
  "\0\0\377\31\31\31\377!!!\377$$$\377\"\"\"\377\30\30\30\377$$$\377\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0""7\377\201\3\377\377\377\4\275\267\256\200\275\270\237\353"
  "\306\272\232\377\206uN\377dS.\375\203rZ\377\273\253\226\276\357\346\325"
  "\252\374\362\331s\365\347\272\37^hC\3\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0OOO\325\15\15\15\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\2\2\2\377\34\34\34\377'''\377!!!\377\12\12\12\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\5\5\5\377MMM\377\377\377\377\0\377\377"
  "\377\0WWW*\25\25\25\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\23\23\23\377%%%\377\26\26\26\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\40\40\40\377TTTU\377\377\377\0\377\377\377\0$$$\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\16\16\16\377\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\14\14\14\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377###\377"
  "\377\377\377\0\377\377\377\0\377\377\377\0""777\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\24\24\24\377\27\27\27\377\32\32\32\377"
  "\32\32\32\377\31\31\31\377\21\21\21\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377>>>\377\377\377\377\0\377\377\377\0&&&\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\5\5\5\377PPP\307\377\377\377\0\377"
  "\377\377\0""888\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "777\377\377\377\377\0\377\377\377\0\10\10\10\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\1\1\1\377\0\0\0\377222\307\377\377\377\0\377\377\377\0,,,"
  "\377\17\17\17\377\34\34\34\377!!!\377!!!\377\34\34\34\377\3\3\3\377\""
  "\"\"\377\"\"\"\377\10\10\10\377!!!\377$$$\377$$$\377!!!\377\16\16\16"
  "\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\354\346\314y\217\205r\37382\33\377"
  "JC-\377l\\.\377\203mO\377\274\251\233\270\341\324\251\36\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;;;\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\34\34\34\377\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0""444\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\27\27\27\377MMM\343\377\377\377\0\377"
  "\377\377\0\377\377\377\0\21\21\21\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\"\"\"\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0SSSq\1\1\1\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377:::\377\377\377\377\0\377\377\377\0VVV8\7\7\7\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377///\377MMM\361UUUG\377\377\377"
  "\0XXX\16RRR\216<<<\377\1\1\1\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377444\377\377\377\377\0\377\377\377\0\21\21\21\377\0\0\0\377\0\0\0"
  "\377\0\0\0\377\0\0\0\377\33\33\33\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0PPP\307\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\25"
  "\25\25\377\377\377\377\0\377\377\377\0\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\377\377\377\0\377\377\377\0""555c\7\7"
  "\7\377\27\27\27\377!!!\377!!!\377\35\35\35\377\7\7\7\377(((\377\377\377"
  "\377\0\377\377\377\0\27\27\27\377\31\31\31\377!!!\377###\377\37\37\37"
  "\377\25\25\25\377%%%\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\0"
  "\0\0\1\201\177\200\10\330\314\272\205\326\317\263\377\321\304\232\376"
  "\301\253\217\377H6!\377VH,\377\311\271\244\333\377\375\374\32\3\377\36"
  "\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0""333\377\1"
  "\1\1\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\12\12\12\377<<<\377"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0TTTc\40\40\40"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\32\32\32\377III\377\377\377\377"
  "\0\377\377\377\0\377\377\377\0WWW*\10\10\10\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377444\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0III\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377CCC\377\377\377\377\0\377\377\377\0""444\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\10\10\10\377MMM\377\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0TTTc\22"
  "\22\22\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\36\36\36\377\377\377"
  "\377\0RRR\216\1\1\1\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377555\377"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\27\27\27\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377UUUU:::\16\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\23\23\23\377\377\377\377\0\377"
  "\377\377\0\0\0\0\377\0\0\0\377\14\14\14\377\22\22\22\377\24\24\24\377"
  "\7\7\7\377%%%\377\377\377\377\0\377\377\377\0\377\377\377\0""555\177"
  "\14\14\14\377\37\37\37\377\"\"\"\377!!!\377\34\34\34\377\14\14\14\377"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\337\355\377\4\334\327\315"
  "E\263\253\233\377\225\214w\375\310\272\230\377jN\"\377\204pJ\375vk^\334"
  "\377\377\373*\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0UUUG;;;\377\34\34\34\377\1\1\1\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\2\2\2\377\24"
  "\24\24\377---\377EEE\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0MMM\377,,,\377\10\10\10\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\16\16\16\377"
  "444\377KKK\377\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0XXX*\13\13\13\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377MMM\377\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0MMM\361\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\7\7\7\377R"
  "RR\216\377\377\377\0\377\377\377\0\17\17\17\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377;;;\377\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0...\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\27\27\27\377\377\377\377\0TTTU\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377HHH\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0>>>\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377SSSq777U\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377(((\377\377\377\377\0\36\36\36\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\35\35\35\377\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\37\37\37\377\27\27\27\377\35\35"
  "\35\377\36\36\36\377\31\31\31\377\22\22\22\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\224\201ZC\254\241\205\335\251\241\211\377H@2\377"
  "hX>\377\224zC\377\307\262\177\335\303\277\260@\377\377\377\0\316\377"
  "F\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0RRR\216BBB\377777\377///\377...\377,,,"
  "\377000\377555\377===\377LLL\377\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0WWW\16EEE\377:::\377111\377000\377000\377444\377"
  "===\377III\377WWW\34\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0MMM\377777\377000\377555\377III\377"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0III\377333\377---\377555"
  "\377KKK\377\377\377\377\0\377\377\377\0\377\377\377\0QQQ\234777\377."
  "..\377000\377@@@\377WWW\34\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0AAA\377222\377000\377===\377QQQ\252\377\377\377\0\377\377\377\0KKK"
  "\377555\377---\377///\377BBB\377\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0EEE\377111\377000\377"
  "888\377LLL\377\377\377\377\0\377\377\377\0'''\377\27\27\27\377\16\16"
  "\16\377\22\22\22\377(((\377\377\377\377\0\377\377\377\0\377\377\377\0"
  "***\377\31\31\31\377\22\22\22\377\30\30\30\377$$$\377\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0***\377\25\25\25\377\23\23\23\377\34\34\34\377111\343\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\344\334\315H\313\300\247\321\276\260\221\377\306"
  "\270\226\376\202tU\377aR7\377\256\233z\271\377\356\3050\377\377\377\0"
  "\0\337\21\1\357\377$\2\377\0\377\1\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\363\354"
  "\333W\222\206r\326\205va\377\260\240\202\377\246\217j\376\257\224r\377"
  "\300\256\225\336\313\303\261[\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\271\354\377\5\365\356\315"
  "\\\201pU\351\322\306\264\377\250\223r\376\270\246\210\377\333\312\264"
  "\340\363\334\3158\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\335\306\237"
  "%znW\365\267\246\213\377\262\241\203\377\320\306\261\334\340\364\340"
  "\23\377\377\377\0\377\0\347\1\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\313C\10\4\346\323\222\22"
  "\315\310\271\276\310\275\245\266\334\317\270\221\375\353\332<\377\377"
  "\377\0\377\377p\1\340\377\1\1\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\300"
  "\1\351\347\333\25\360\356\334\40\377\377\377\12\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0"};

static image_entry image_data[] = {
    { "guitar", guitar },
	{ NULL, NULL },
};

static void render (GtkWidget *wi, cairo_t* cr) {

    // get widget dimension
    double rect_width  = wi->allocation.width-4.;
	double rect_height = wi->allocation.height-4.;
    double x0      = wi->allocation.x+2.;
	double y0      = wi->allocation.y+2.;

    // set transparent operator
    cairo_set_source_rgba (cr, 1.0f, 1.0f, 1.0f, 0.0f);
	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
	cairo_paint (cr);

    // get image
    GdkPixbuf *stock_image;
    image_entry *p = image_data;
G_GNUC_BEGIN_IGNORE_DEPRECATIONS
    stock_image = gdk_pixbuf_new_from_inline(
                -1,p->icon_data , FALSE, NULL);
G_GNUC_END_IGNORE_DEPRECATIONS

    // draw background
    double radius = 38.;
	double x1,y1;
	x1=x0+rect_width;
	y1=y0+rect_height;

	cairo_move_to  (cr, x0, y0 + radius);
	cairo_curve_to (cr, x0 , y0, x0 , y0, x0 + radius, y0);
	cairo_line_to (cr, x1 - radius, y0);
	cairo_curve_to (cr, x1, y0, x1, y0, x1, y0 + radius);
	cairo_line_to (cr, x1 , y1 - radius);
	cairo_curve_to (cr, x1, y1, x1, y1, x1 - radius, y1);
	cairo_line_to (cr, x0 + radius, y1);
	cairo_curve_to (cr, x0, y1, x0, y1, x0, y1- radius);
	cairo_close_path (cr);

    cairo_pattern_t*pat;
	pat = cairo_pattern_create_linear (0, y0, 0, y1);
	cairo_pattern_add_color_stop_rgb (pat, 1, 0, 0, 0.23);
	cairo_pattern_add_color_stop_rgb (pat, 0.5, 0.35, 0.35, 0.35);
	cairo_pattern_add_color_stop_rgb (pat, 0, 0.12, 0.12, 0.12);
	cairo_set_source (cr, pat);
	cairo_fill_preserve (cr);
    cairo_set_line_width(cr, 2.0);
	cairo_set_source_rgb (cr, 0., 0., 0.);
    cairo_stroke (cr);
    // add text
    cairo_move_to(cr,40., 65.);
    cairo_set_font_size (cr, 12);
	cairo_text_path (cr,"GNU/Linux virtual guitar amplifier");
	cairo_set_line_width(cr, 1.0);
	cairo_set_source_rgb (cr, 0., 0., 0.);
    cairo_stroke (cr);
    // draw image
	GdkGC *gc = gdk_gc_new(GDK_DRAWABLE(wi->window));
    gdk_draw_pixbuf(GDK_DRAWABLE(wi->window), gc,
	                stock_image, 0, 0,
	                x0+20, y0+5, -1,-1,
	                GDK_RGB_DITHER_NORMAL, 0, 0);
    
    g_object_unref(stock_image);
	g_object_unref(gc);

}

void make_transparency(GtkWidget* wi) {

    // get widget dimension
    gint rect_width  = wi->allocation.width;
	gint rect_height = wi->allocation.height;

    // make Image to fake transparency
	static GdkBitmap* ShapeBitmap = NULL;
	static cairo_t* cr = NULL;

	ShapeBitmap = gdk_pixmap_new(NULL, rect_width, rect_height, 1);
	if (ShapeBitmap) {
		cr = gdk_cairo_create (ShapeBitmap);
		if (cairo_status (cr) == CAIRO_STATUS_SUCCESS) {
			render (wi, cr);
			cairo_destroy (cr);
            // make widget invisible
            gtk_widget_shape_combine_mask (wi, NULL, 0, 0);
            // set sharp mask to visible part
            gtk_widget_shape_combine_mask (wi, ShapeBitmap, 0, 0);
		}
		g_object_unref(ShapeBitmap);
	}
}

gboolean splash_expose(GtkWidget *wi, GdkEventExpose *ev, gpointer user_data)
{
    cairo_t* cr = NULL;
	cr = gdk_cairo_create (wi->window);
	if (!cr) return FALSE;

    static bool ms = true;
    if(ms) {
        make_transparency(wi);
        ms = false;
    }
    render (wi, cr);
	cairo_destroy (cr);
    return FALSE;
}

gboolean rectangle_skin_color_expose(GtkWidget *wi, GdkEventExpose *ev, gpointer user_data)
{
    cairo_t *cr;
	/* create a cairo context */
	cr = gdk_cairo_create(wi->window);
	GdkRegion *region;
	region = gdk_region_rectangle (&wi->allocation);
	gdk_region_intersect (region, ev->region);
	gdk_cairo_region (cr, region);
	cairo_clip (cr);

	double x0      = wi->allocation.x+2;
	double y0      = wi->allocation.y+2;
	double rect_width  = wi->allocation.width-2;
	double rect_height = wi->allocation.height-2;

	cairo_rectangle (cr, x0,y0,rect_width,rect_height+1);
	cairo_set_source_rgb (cr, 0, 0, 0);
	cairo_fill (cr);

	cairo_pattern_t*pat =
	cairo_pattern_create_linear (0, y0, 0, y0+rect_height);
		//cairo_pattern_create_radial (-50, y0, 5,rect_width-10,  rect_height, 20.0);
	cairo_pattern_add_color_stop_rgba (pat, 0, 0.2, 0.2, 0.3, 0.6);
    cairo_pattern_add_color_stop_rgba (pat, 1, 0.05, 0.05, 0.05, 0.6);
	cairo_set_source (cr, pat);
	cairo_rectangle (cr, x0+1,y0+1,rect_width-2,rect_height-1);
	cairo_fill (cr);

	cairo_pattern_destroy (pat);
	cairo_destroy(cr);
	gdk_region_destroy (region);
	return FALSE;
    
}

gboolean conv_widget_expose(GtkWidget *wi, GdkEventExpose *ev, gpointer user_data)
{
	cairo_t *cr;
	cairo_pattern_t *pat;

	/* create a cairo context */
	cr = gdk_cairo_create(wi->window);
    GdkRegion *region;
	region = gdk_region_rectangle (&wi->allocation);
	gdk_region_intersect (region, ev->region);
	gdk_cairo_region (cr, region);
	cairo_clip (cr);

	double x0      = wi->allocation.x+5;
	double y0      = wi->allocation.y+5;
	double rect_width  = wi->allocation.width-10;
	double rect_height = wi->allocation.height-10;
	double radius = 36.;
	double x1,y1;
	x1=x0+rect_width;
	y1=y0+rect_height;

	cairo_move_to  (cr, x0, y0 + radius);
	cairo_curve_to (cr, x0 , y0, x0 , y0, x0 + radius, y0);
	cairo_line_to (cr, x1 - radius, y0);
	cairo_curve_to (cr, x1, y0, x1, y0, x1, y0 + radius);
	cairo_line_to (cr, x1 , y1 - radius);
	cairo_curve_to (cr, x1, y1, x1, y1, x1 - radius, y1);
	cairo_line_to (cr, x0 + radius, y1);
	cairo_curve_to (cr, x0, y1, x0, y1, x0, y1- radius);
	cairo_close_path (cr);

	pat = cairo_pattern_create_linear (0, y0, 0, y1);
    cairo_pattern_add_color_stop_rgba (pat, 1, 0., 0., 0., 0.8);
    cairo_pattern_add_color_stop_rgba (pat, 0, 0, 0, 0, 0.4);
    cairo_set_source (cr, pat);
    cairo_fill_preserve (cr);

	cairo_set_source_rgba (cr, 0, 0, 0, 0.8);
	cairo_set_line_width (cr, 9.0);
	cairo_stroke (cr);

	cairo_move_to  (cr, x0, y0 + radius);
	cairo_curve_to (cr, x0 , y0, x0 , y0, x0 + radius, y0);
	cairo_line_to (cr, x1 - radius, y0);
	cairo_curve_to (cr, x1, y0, x1, y0, x1, y0 + radius);
	cairo_line_to (cr, x1 , y1 - radius);
	cairo_curve_to (cr, x1, y1, x1, y1, x1 - radius, y1);
	cairo_line_to (cr, x0 + radius, y1);
	cairo_curve_to (cr, x0, y1, x0, y1, x0, y1- radius);
	cairo_close_path (cr);

	cairo_set_source_rgb (cr, 0.2, 0.2, 0.2);
	cairo_set_line_width (cr, 1.0);
	cairo_stroke (cr);

	cairo_pattern_destroy (pat);
	cairo_destroy(cr);
    gdk_region_destroy (region);
    
	return FALSE;
}

gboolean error_box_expose(GtkWidget *wi, GdkEventExpose *ev, gpointer user_data)
{
	cairo_t *cr;
	/* create a cairo context */
	cr = gdk_cairo_create(wi->window);
    GdkRegion *region;
	region = gdk_region_rectangle (&wi->allocation);
	gdk_region_intersect (region, ev->region);
	gdk_cairo_region (cr, region);
	cairo_clip (cr);

	double x0      = wi->allocation.x+2;
	double y0      = wi->allocation.y+2;
	double rect_width  = wi->allocation.width-4;
	double rect_height = wi->allocation.height-4;

    cairo_rectangle (cr, x0-1,y0-1,rect_width+2,rect_height+2);
    cairo_set_source_rgb (cr, 0, 0, 0);
    cairo_set_line_width(cr, 2.0);
    cairo_stroke(cr);

	cairo_pattern_t*pat = cairo_pattern_create_linear (x0, y0+50,x0, y0);
    cairo_pattern_set_extend(pat, CAIRO_EXTEND_REFLECT);
    
    cairo_pattern_add_color_stop_rgba (pat, 0, 0.5, 0.02, 0.03, 0.6);
    cairo_pattern_add_color_stop_rgba (pat, 1, 0.05, 0.05, 0.1, 0.6);

	cairo_set_source (cr, pat);
	cairo_rectangle (cr, x0+2,y0+2,rect_width-4,rect_height-4);
	cairo_fill (cr);

	cairo_rectangle (cr, x0+8,y0+31,rect_width-16,rect_height-75);
	cairo_set_source_rgb (cr, 0.5, 0.5, 0.5);
    cairo_set_line_width(cr, 2.0);
	cairo_stroke_preserve(cr);
	pat = cairo_pattern_create_linear (x0, y0+50,x0, y0);
    cairo_pattern_set_extend(pat, CAIRO_EXTEND_REFLECT);
    cairo_pattern_add_color_stop_rgba (pat, 0, 0.8, 0.8, 0.8, 0.6);
    cairo_pattern_add_color_stop_rgba (pat, 1, 0.3, 0.3, 0.3, 0.6);
    cairo_set_source (cr, pat);
	cairo_fill (cr);

    cairo_set_source_rgb(cr,  0.2, 0.2, 0.2);
    cairo_set_line_width(cr, 2.0);
    cairo_move_to(cr,x0+rect_width-3, y0+3);
    cairo_line_to(cr, x0+rect_width-3, y0+rect_height-2);
    cairo_line_to(cr, x0+2, y0+rect_height-2);
    cairo_stroke(cr);

    cairo_set_source_rgb(cr,  0.1, 0.1, 0.1);
    cairo_set_line_width(cr, 2.0);
    cairo_move_to(cr,x0+3, y0+rect_height-1);
    cairo_line_to(cr, x0+3, y0+3);
    cairo_line_to(cr, x0+rect_width-3, y0+3);
    cairo_stroke(cr);

    cairo_set_source_rgb(cr,  0.5, 0.5, 0.5);
    cairo_set_line_width(cr, 1.5);
    cairo_arc (cr, x0+7, y0+7, 1.5, 0, 2*M_PI);
    cairo_move_to(cr,x0+rect_width-8, y0+7);
    cairo_arc (cr, x0+rect_width-7, y0+7, 1.5, 0, 2*M_PI);
    cairo_move_to(cr,x0+rect_width-7, y0+rect_height-6);
    cairo_arc (cr, x0+rect_width-7, y0+rect_height-6, 1.5, 0, 2*M_PI);
    cairo_move_to(cr,x0+7, y0+rect_height-6);
    cairo_arc (cr, x0+7, y0+rect_height-6, 1.5, 0, 2*M_PI);
    cairo_stroke_preserve(cr);
    cairo_set_source_rgb(cr,  0.1, 0.1, 0.1);
    cairo_fill (cr);

    cairo_pattern_destroy (pat);
	cairo_destroy(cr);
    gdk_region_destroy (region);
    
	return FALSE;
}

gboolean start_box_expose(GtkWidget *wi, GdkEventExpose *ev, gpointer user_data)
{
	cairo_t *cr;
	/* create a cairo context */
	cr = gdk_cairo_create(wi->window);
    GdkRegion *region;
	region = gdk_region_rectangle (&wi->allocation);
	gdk_region_intersect (region, ev->region);
	gdk_cairo_region (cr, region);
	cairo_clip (cr);

	double x0      = wi->allocation.x+1;
	double y0      = wi->allocation.y+1;
	double rect_width  = wi->allocation.width-2;
	double rect_height = wi->allocation.height-2;

    cairo_rectangle (cr, x0-1,y0-1,rect_width+2,rect_height+2);
    cairo_set_source_rgb (cr, 0, 0, 0);
    cairo_set_line_width(cr, 2.0);
    cairo_stroke(cr);

	cairo_pattern_t*pat = cairo_pattern_create_linear (x0, y0+rect_height/2,x0, y0);
    cairo_pattern_set_extend(pat, CAIRO_EXTEND_REFLECT);
    
    cairo_pattern_add_color_stop_rgba (pat, 0, 0.1, 0.1, 0.2, 0.6);
    cairo_pattern_add_color_stop_rgba (pat, 1, 0.05, 0.05, 0.05, 0.6);

	cairo_set_source (cr, pat);
	cairo_rectangle (cr, x0+2,y0+2,rect_width-4,rect_height-4);
	cairo_fill (cr);

	cairo_rectangle (cr, x0+8,y0+31,rect_width-16,rect_height-75);
	cairo_set_source_rgb (cr, 0.5, 0.5, 0.5);
    cairo_set_line_width(cr, 2.0);
	cairo_stroke_preserve(cr);
	pat = cairo_pattern_create_linear (x0+8, y0+rect_height/2-37,x0, y0);
    cairo_pattern_set_extend(pat, CAIRO_EXTEND_REFLECT);
    cairo_pattern_add_color_stop_rgba (pat, 0, 0.2, 0.2, 0.3, 0.6);
    cairo_pattern_add_color_stop_rgba (pat, 1, 0.05, 0.05, 0.05, 0.6);
    cairo_set_source (cr, pat);
	cairo_fill (cr);

    cairo_set_source_rgb(cr,  0.2, 0.2, 0.2);
    cairo_set_line_width(cr, 2.0);
    cairo_move_to(cr,x0+rect_width-3, y0+3);
    cairo_line_to(cr, x0+rect_width-3, y0+rect_height-2);
    cairo_line_to(cr, x0+2, y0+rect_height-2);
    cairo_stroke(cr);

    cairo_set_source_rgb(cr,  0.1, 0.1, 0.1);
    cairo_set_line_width(cr, 2.0);
    cairo_move_to(cr,x0+3, y0+rect_height-1);
    cairo_line_to(cr, x0+3, y0+3);
    cairo_line_to(cr, x0+rect_width-3, y0+3);
    cairo_stroke(cr);

    cairo_set_source_rgb(cr,  0.5, 0.5, 0.5);
    cairo_set_line_width(cr, 1.5);
    cairo_arc (cr, x0+7, y0+7, 1.5, 0, 2*M_PI);
    cairo_move_to(cr,x0+rect_width-8, y0+7);
    cairo_arc (cr, x0+rect_width-7, y0+7, 1.5, 0, 2*M_PI);
    cairo_move_to(cr,x0+rect_width-7, y0+rect_height-6);
    cairo_arc (cr, x0+rect_width-7, y0+rect_height-6, 1.5, 0, 2*M_PI);
    cairo_move_to(cr,x0+7, y0+rect_height-6);
    cairo_arc (cr, x0+7, y0+rect_height-6, 1.5, 0, 2*M_PI);
    cairo_stroke_preserve(cr);
    cairo_set_source_rgb(cr,  0.1, 0.1, 0.1);
    cairo_fill (cr);

    cairo_pattern_destroy (pat);
	cairo_destroy(cr);
    gdk_region_destroy (region);

	return FALSE;
}
}
